@@ -2,6 +2,9 @@
 /* Generated data (by glib-mkenums) */
 
 #include "soup.h"
+#define LIBSOUP_USE_UNSTABLE_REQUEST_API
+#include "soup-cache.h"
+#include "soup-requester.h"
 /* enumerations from "soup-address.h" */
 GType
 soup_address_family_get_type (void)
@@ -19,6 +22,55 @@ soup_address_family_get_type (void)
 	return etype;
 }
 
+/* enumerations from "soup-cache.h" */
+GType
+soup_cacheability_get_type (void)
+{
+	static GType etype = 0;
+	if (G_UNLIKELY (etype == 0)) {
+		static const GFlagsValue values[] = {
+			{ SOUP_CACHE_CACHEABLE, "SOUP_CACHE_CACHEABLE", "cacheable" },
+			{ SOUP_CACHE_UNCACHEABLE, "SOUP_CACHE_UNCACHEABLE", "uncacheable" },
+			{ SOUP_CACHE_INVALIDATES, "SOUP_CACHE_INVALIDATES", "invalidates" },
+			{ SOUP_CACHE_VALIDATES, "SOUP_CACHE_VALIDATES", "validates" },
+			{ 0, NULL, NULL }
+		};
+		etype = g_flags_register_static (g_intern_static_string ("SoupCacheability"), values);
+	}
+	return etype;
+}
+
+GType
+soup_cache_response_get_type (void)
+{
+	static GType etype = 0;
+	if (G_UNLIKELY (etype == 0)) {
+		static const GEnumValue values[] = {
+			{ SOUP_CACHE_RESPONSE_FRESH, "SOUP_CACHE_RESPONSE_FRESH", "fresh" },
+			{ SOUP_CACHE_RESPONSE_NEEDS_VALIDATION, "SOUP_CACHE_RESPONSE_NEEDS_VALIDATION", "needs-validation" },
+			{ SOUP_CACHE_RESPONSE_STALE, "SOUP_CACHE_RESPONSE_STALE", "stale" },
+			{ 0, NULL, NULL }
+		};
+		etype = g_enum_register_static (g_intern_static_string ("SoupCacheResponse"), values);
+	}
+	return etype;
+}
+
+GType
+soup_cache_type_get_type (void)
+{
+	static GType etype = 0;
+	if (G_UNLIKELY (etype == 0)) {
+		static const GEnumValue values[] = {
+			{ SOUP_CACHE_SINGLE_USER, "SOUP_CACHE_SINGLE_USER", "single-user" },
+			{ SOUP_CACHE_SHARED, "SOUP_CACHE_SHARED", "shared" },
+			{ 0, NULL, NULL }
+		};
+		etype = g_enum_register_static (g_intern_static_string ("SoupCacheType"), values);
+	}
+	return etype;
+}
+
 /* enumerations from "soup-cookie-jar.h" */
 GType
 soup_cookie_jar_accept_policy_get_type (void)
@@ -82,8 +134,8 @@ soup_http_version_get_type (void)
 	static GType etype = 0;
 	if (G_UNLIKELY (etype == 0)) {
 		static const GEnumValue values[] = {
-			{ SOUP_HTTP_1_0, "SOUP_HTTP_1_0", "0" },
-			{ SOUP_HTTP_1_1, "SOUP_HTTP_1_1", "1" },
+			{ SOUP_HTTP_1_0, "SOUP_HTTP_1_0", "http-1-0" },
+			{ SOUP_HTTP_1_1, "SOUP_HTTP_1_1", "http-1-1" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static (g_intern_static_string ("SoupHTTPVersion"), values);
@@ -214,6 +266,22 @@ soup_connection_state_get_type (void)
 	return etype;
 }
 
+/* enumerations from "soup-requester.h" */
+GType
+soup_requester_error_get_type (void)
+{
+	static GType etype = 0;
+	if (G_UNLIKELY (etype == 0)) {
+		static const GEnumValue values[] = {
+			{ SOUP_REQUESTER_ERROR_BAD_URI, "SOUP_REQUESTER_ERROR_BAD_URI", "bad-uri" },
+			{ SOUP_REQUESTER_ERROR_UNSUPPORTED_URI_SCHEME, "SOUP_REQUESTER_ERROR_UNSUPPORTED_URI_SCHEME", "unsupported-uri-scheme" },
+			{ 0, NULL, NULL }
+		};
+		etype = g_enum_register_static (g_intern_static_string ("SoupRequesterError"), values);
+	}
+	return etype;
+}
+
 /* enumerations from "soup-socket.h" */
 GType
 soup_socket_io_status_get_type (void)
