@@ -6,8 +6,7 @@
 #ifndef SOUP_TYPES_H
 #define SOUP_TYPES_H 1
 
-#include <glib/gtypes.h>
-#include <glib-object.h>
+#include <gio/gio.h>
 
 #include <libsoup/soup-status.h>
 
@@ -17,6 +16,7 @@ typedef struct _SoupAddress           SoupAddress;
 typedef struct _SoupAuth              SoupAuth;
 typedef struct _SoupAuthDomain        SoupAuthDomain;
 typedef struct _SoupCookie            SoupCookie;
+typedef struct _SoupCookieJar         SoupCookieJar;
 typedef struct _SoupDate              SoupDate;
 typedef struct _SoupMessage           SoupMessage;
 typedef struct _SoupServer            SoupServer;
@@ -27,6 +27,11 @@ typedef struct _SoupSessionSync       SoupSessionSync;
 typedef struct _SoupSocket            SoupSocket;
 typedef struct _SoupURI               SoupURI;
 
+/*< private >*/
+typedef struct _SoupConnection        SoupConnection;
+typedef struct _SoupMessageQueue      SoupMessageQueue;
+typedef struct _SoupMessageQueueItem  SoupMessageQueueItem;
+
 G_END_DECLS
 
 #endif
